@@ -633,10 +633,10 @@ EOM
       yq -i ".cms_nfs.server=${filestore_ip}" ${PRODUCTSVAR_FILE}
       yq -i ".cms_nfs.path=${filestore_share}" ${PRODUCTSVAR_FILE}
 
-      echo "[INFO] Update NFS mountOptions [nfsvers=3]"
-      yq -i '.cms_nfs.mountOptions[0]="nfsvers=3"' ${PRODUCTSVAR_FILE}
-      yq -i '.cms_pvc.cmscontent.mountOptions[0]="nfsvers=3"' ${PRODUCTSVAR_FILE}
-      yq -i '.cms_pvc.backuprestore.mountOptions[0]="nfsvers=3"' ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update NFS mountOptions [nfsvers=3.0]"
+      yq -i '.cms_nfs.mountOptions[0]="nfsvers=3.0"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_pvc.cmscontent.mountOptions[0]="nfsvers=3.0"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_pvc.backuprestore.mountOptions[0]="nfsvers=3.0"' ${PRODUCTSVAR_FILE}
 
       if [[ -z "$IMAGE_REGISTRY" ]] && [[ -z "$GCP_GCR" ]]; then
         echo "[ERROR] Both image_registry and gcp_gcr are empty, make sure one of them has proper value provided in cms.var file."
@@ -866,7 +866,7 @@ EOM
     fi
 
     # Modification for cloud deployment cases
-    
+
     if [[ -n ${CLOUDPLATFORM} ]]; then
       # Update the External static IP (No need to create LoadBalancer in advance)
       external_vip=$(grep OUTPUT_EXTERNAL_VIP ${CLOUD_ENV} | awk -F '=' '{print $2}')
@@ -895,7 +895,7 @@ EOM
 
       outbound_ip=$(grep OUTPUT_OUTBOUND_IP ${CLOUD_ENV} | awk -F '=' '{print $2}')
       if [[ -z "$outbound_ip" ]]; then
-        echo "[WARNING] OUTPUT_OUTBOUND_IP is empty or not found, skip adding it to lbWhiteList."
+       echo "[WARNING] OUTPUT_OUTBOUND_IP is empty or not found, skip adding it to lbWhiteList."
         OUTBOUND_IP_sed="[]"
       else
         OUTBOUND_IP_sed="[$(echo $outbound_ip | sed -e 's/"//g')\/32]"
@@ -917,7 +917,7 @@ EOM
 
       echo "[INFO] Updating cms_haproxy lbWhiteList ${LB_WHITE_LIST_sed}"
       sed -i '/^cms_haproxy:/{:a;N;/  lbWhiteList:.*/!{$!ba};s/  lbWhiteList:.*/  lbWhiteList: '$LB_WHITE_LIST_sed'/}' ${PRODUCTSVAR_FILE}
-      
+
       echo "[INFO] Set cms_haproxy lbWhiteList to ${LB_WHITE_LIST_sed}."
 
 
@@ -928,6 +928,10 @@ EOM
 
         echo "[INFO] Added outbound IP to cms_haproxy lbWhiteList :${LB_WHITE_LIST_sed2}."
       fi
+      
+      LB_WHITE_LIST_sed2=$(echo $OUTBOUND_IP_sed|sed -e 's/]/,/g')$(echo $LB_WHITE_LIST_sed|sed -e 's/\[//g')     
+      echo "[INFO] Updating cms_haproxy lbWhiteList ${LB_WHITE_LIST_sed2}"
+      sed -i '/^cms_haproxy:/{:a;N;/  lbWhiteList:.*/!{$!ba};s/  lbWhiteList:.*/  lbWhiteList: '$LB_WHITE_LIST_sed2'/}' ${PRODUCTSVAR_FILE}
 
       # Update database storageclass and PV size
       # Common setting for both AKS and GKE
